@@ -6,8 +6,10 @@ import json
 import logging
 
 import numpy as np
+from flex.extensions.bindata import BinaryDataExtension
 from .persistence import IPersist
 
+
 logger = logging.getLogger(__name__)
 
 _citation_asplund2009 = r"""
@@ -192,11 +194,11 @@ class Abund(IPersist):
         nuclei of each element in any form relative to the total for
         all elements in any form. For the Sun, the abundance values
         of H, He, and Li are approximately 0.92, -1.11, and -11.0.
-    'n/nTot' - Abundance values are log10 of the fraction of nuclei
+    'n/nTot' - Abundance values are the fraction of nuclei
         of each element in any form relative to the total for all
         elements in any form. For the Sun, the abundance values of
         H, He, and Li are approximately 0.92, 0.078, and 1.03e-11.
-    'n/nH' - Abundance values are log10 of the fraction of nuclei
+    'n/nH' - Abundance values are the fraction of nuclei
         of each element in any form relative to the number of
         hydrogen nuclei in any form. For the Sun, the abundance
         values of H, He, and Li are approximately 1, 0.085, and
@@ -236,9 +238,7 @@ class Abund(IPersist):
         return self.totype(pattern, type, raw=raw)
 
     def __getitem__(self, elem):
-        pattern = self.get_pattern(self.type, raw=True)
-        i = self._get_index(elem)
-        return pattern[i]
+        return self.get_element(elem)
 
     def __setitem__(self, elem, abund):
         self.update_pattern({elem: abund})
@@ -270,6 +270,9 @@ class Abund(IPersist):
                     out += "\n"
             return out
 
+    def __repr__(self):
+        return self.__str__()
+
     # These are there for the atmosphere interpolation
     # The internal format is always H=12, so that should be fine
     def __add__(self, other):
@@ -294,11 +297,21 @@ class Abund(IPersist):
                 f"Got element abreviation {elem}, expected one of {elements}"
             )
 
+    def __copy__(self):
+        pattern = self._pattern.copy()
+        other = Abund(
+            monh=self.monh,
+            type=self.type,
+            pattern=pattern,
+            citation_info=self.citation_info,
+        )
+        return other
+
     @staticmethod
     def fromtype(pattern, fromtype, raw=False):
         """Return a copy of the input abundance pattern, transformed from
         the input type to the 'H=12' type. Valid abundance pattern types
-        are 'sme', 'n/nTot', 'n/nH', and 'H=12'.
+        are 'sme', 'n/nTot', 'n/nH', 'n/nFe', and 'H=12'.
         """
         elem = elements
 
@@ -321,10 +334,17 @@ class Abund(IPersist):
             abund = 12 + np.log10(abund)
         elif type == "n/nh":
             abund = 12 + np.log10(abund)
+        elif type == "n/nfe":
+            abund /= abund[0]
+            abund = 12 + np.log10(abund)
+        elif type == "fe=12":
+            abund = 10 ** (abund - 12)
+            abund /= abund[0]
+            abund = 12 + np.log10(abund)
         else:
             raise ValueError(
                 "got abundance type '{}',".format(type)
-                + " should be 'H=12', 'n/nH', 'n/nTot', or 'sme'"
+                + " should be 'H=12', 'n/nH', 'n/nTot', 'n/nFe', 'Fe=12', or 'sme'"
             )
         if raw:
             return abund
@@ -358,10 +378,19 @@ class Abund(IPersist):
             abund /= np.nansum(abund)
         elif type == "n/nh":
             abund = 10 ** (abund - 12)
+        elif type == "n/nfe":
+            idx_fe = elements_dict["Fe"]
+            abund = 10 ** (abund - 12)
+            abund /= abund[idx_fe]
+        elif type == "fe=12":
+            idx_fe = elements_dict["Fe"]
+            abund = 10 ** (abund - 12)
+            abund /= abund[idx_fe]
+            abund = np.log10(abund) + 12
         else:
             raise ValueError(
                 "got abundance type '{}',".format(type)
-                + " should be 'H=12', 'n/nH', 'n/nTot', or 'sme'"
+                + " should be 'H=12', 'n/nH', 'n/nTot', 'n/nFe', 'Fe=12', or 'sme'"
             )
 
         if raw:
@@ -369,11 +398,7 @@ class Abund(IPersist):
         else:
             return {el: abund[elements_dict[el]] for el in elements}
 
-    _formats = ["H=12", "sme", "n/nTot", "n/nH"]
-
-    # fmt: off
-
-    # fmt: on
+    _formats = ["H=12", "sme", "n/nTot", "n/nH", "n/nFe", "Fe=12"]
 
     @property
     def elem(self):
@@ -382,6 +407,11 @@ class Abund(IPersist):
         """
         return elements
 
+    @property
+    def elem_dict(self):
+        """ Return the position of each element in the raw array """
+        return elements_dict
+
     @property
     def monh(self):
         """float: Metallicity, the logarithmic offset added to
@@ -413,10 +443,10 @@ class Abund(IPersist):
         """
         self.type = "H=12"
         self.citation_info = _citation_atomic_weights + "\n"
-        if pattern_name.lower() in ["asplund2009", "solar"]:
+        if pattern_name.lower() in ["asplund2009"]:
             self._pattern = np.array(_asplund2009, dtype=float)
             self.citation_info += _citation_asplund2009
-        elif pattern_name.lower() == "grevesse2007":
+        elif pattern_name.lower() in ["grevesse2007", "solar"]:
             self._pattern = np.array(_grevesse2007, dtype=float)
             self.citation_info += _citation_grevesse2007
         elif pattern_name.lower() == "lodders2003":
@@ -475,6 +505,13 @@ class Abund(IPersist):
             type = self.type
         return self.totype(self._pattern, type, raw=raw)
 
+    def get_element(self, elem, type=None):
+        if type is None:
+            type = self.type
+        pattern = self(type, raw=True)
+        i = self._get_index(elem)
+        return pattern[i]
+
     def empty_pattern(self):
         """Return an abundance pattern with value None for all elements.
         """
@@ -482,7 +519,30 @@ class Abund(IPersist):
         pattern[0] = 0
         return pattern
 
-    def _save(self, file, folder="abund"):
+    def _save(self):
+        header = {
+            "monh": self.monh,
+            "type_internal": self._type_internal,
+            "type": self.type,
+            "citation_info": self.citation_info,
+        }
+        data = self._pattern
+        ext = BinaryDataExtension(header, data)
+        return ext
+
+    @classmethod
+    def _load(cls, ext: BinaryDataExtension):
+        header = ext.header
+        pattern = ext.data
+        abund = cls(
+            monh=header["monh"],
+            pattern=pattern,
+            type=header["type"],
+            citation_info=header["citation_info"],
+        )
+        return abund
+
+    def _save_v1(self, file, folder="abund"):
         """ Save the data to a file handler """
         if folder != "" or folder[-1] != "/":
             folder += "/"
@@ -496,7 +556,7 @@ class Abund(IPersist):
         file.writestr(f"{folder}pattern.npy", b.getvalue())
 
     @staticmethod
-    def _load(file, names, folder=""):
+    def _load_v1(file, names, folder=""):
         """ Load the data from a file handler """
         for name in names:
             if name.endswith("info.json"):
