@@ -51,12 +51,11 @@ def lowercase(func):
     return f
 
 
-def oneof(*options, astype=False):
+def oneof(*options, astype=None):
     def f(self, value):
         if value not in options:
-            if astype is not None:
-                if astype(value) == value:
-                    return astype(value)
+            if astype is not None and astype(value) == value:
+                return astype(value)
             raise ValueError(f"Received {value} but expected one of {options}")
         return value
 
